# -*- coding:utf-8 -*-
from gpiozero import OutputDevice
import serial
import os

relay_pins = [5, 6, 13, 16, 19, 20]

relays = [OutputDevice(pin, initial_value=0) for pin in relay_pins]

ser = serial.Serial("/dev/serial0", 115200, timeout=0.01)  # receive data once every 0.01S
print(ser.portstr)
ser.flushInput()

print("You can always receive data, press Ctrl + C to exit\r\n")

try:
    while True:
        data = ser.readline().decode('utf-8').strip()
        if data:
            print("\nThe data received is: ", data)
            response = ("The data received back is: " + data + "\r\n").encode('utf-8')
            ser.write(response)
            
            for char in data:
                if char.isdigit():
                    relay_index = int(char) - 1
                    relays[relay_index].value = 0
                    print("Turn off Relay {}".format(relay_index + 1))
                    ser.write("Turn off Relay {}\r\n".format(relay_index + 1).encode('utf-8'))
                elif char.lower() in ['a', 'b', 'c', 'd', 'e', 'f']:
                    relay_index = ord(char.lower()) - ord('a')
                    relays[relay_index].value = 1
                    print("Turn on Relay {}".format(relay_index + 1))
                    ser.write("Turn on Relay {}\r\n".format(relay_index + 1).encode('utf-8'))
            
            ser.write("END\n\n".encode('utf-8'))
except KeyboardInterrupt:
    print('Exiting...')
finally:
    ser.close()
    for relay in relays:
        relay.value = 0